tl_debug

Function tl_debug 

pub fn tl_debug() -> bool
Returns true when the FEROGRAM_TL_DEBUG environment variable is set to any non-empty value. The result is cached after the first call so there is zero overhead in hot deserialisation paths when debugging is off.

Enable at runtime:

FEROGRAM_TL_DEBUG=1 cargo run ...