pub struct WebBrowserSettings {
pub open_external_browser: bool,
pub display_close_button: bool,
pub external_exceptions: Vec<WebDomainException>,
pub inapp_exceptions: Vec<WebDomainException>,
pub hash: i64,
}Expand description
Generated from:
account.webBrowserSettings#79eb8cb3 flags:# open_external_browser:flags.0?true display_close_button:flags.1?true external_exceptions:Vector<WebDomainException> inapp_exceptions:Vector<WebDomainException> hash:long = account.WebBrowserSettingsFields
open_external_browser: boolexternal_exceptions: Vec<WebDomainException>inapp_exceptions: Vec<WebDomainException>hash: i64Trait Implementations
Sourceimpl Clone for WebBrowserSettings
impl Clone for WebBrowserSettings
Sourcefn clone(&self) -> WebBrowserSettings
fn clone(&self) -> WebBrowserSettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WebBrowserSettings
impl Debug for WebBrowserSettings
Sourceimpl Deserializable for WebBrowserSettings
impl Deserializable for WebBrowserSettings
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<WebBrowserSettings> for WebBrowserSettings
impl From<WebBrowserSettings> for WebBrowserSettings
Sourcefn from(x: WebBrowserSettings) -> Self
fn from(x: WebBrowserSettings) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for WebBrowserSettings
impl Identifiable for WebBrowserSettings
Sourceconst CONSTRUCTOR_ID: u32 = 0x79eb8cb3
const CONSTRUCTOR_ID: u32 = 0x79eb8cb3
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for WebBrowserSettings
impl PartialEq for WebBrowserSettings
Sourcefn eq(&self, other: &WebBrowserSettings) -> bool
fn eq(&self, other: &WebBrowserSettings) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serializable for WebBrowserSettings
impl Serializable for WebBrowserSettings
impl StructuralPartialEq for WebBrowserSettings
Sourceimpl TryFrom<WebBrowserSettings> for WebBrowserSettings
impl TryFrom<WebBrowserSettings> for WebBrowserSettings
Sourcetype Error = WebBrowserSettings
type Error = WebBrowserSettings
The type returned in the event of a conversion error.