pub struct AccessSettings {
pub restricted: bool,
pub add_users: Option<Vec<User>>,
}Expand description
Generated from:
bots.accessSettings#dd1fbf93 flags:# restricted:flags.0?true add_users:flags.1?Vector<User> = bots.AccessSettingsFields
restricted: booladd_users: Option<Vec<User>>Trait Implementations
Sourceimpl Clone for AccessSettings
impl Clone for AccessSettings
Sourcefn clone(&self) -> AccessSettings
fn clone(&self) -> AccessSettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AccessSettings
impl Debug for AccessSettings
Sourceimpl Deserializable for AccessSettings
impl Deserializable for AccessSettings
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<AccessSettings> for AccessSettings
impl From<AccessSettings> for AccessSettings
Sourcefn from(x: AccessSettings) -> Self
fn from(x: AccessSettings) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for AccessSettings
impl Identifiable for AccessSettings
Sourceconst CONSTRUCTOR_ID: u32 = 0xdd1fbf93
const CONSTRUCTOR_ID: u32 = 0xdd1fbf93
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for AccessSettings
impl PartialEq for AccessSettings
Sourcefn eq(&self, other: &AccessSettings) -> bool
fn eq(&self, other: &AccessSettings) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serializable for AccessSettings
impl Serializable for AccessSettings
Sourceimpl TryFrom<AccessSettings> for AccessSettings
impl TryFrom<AccessSettings> for AccessSettings
Sourcetype Error = AccessSettings
type Error = AccessSettings
The type returned in the event of a conversion error.
impl StructuralPartialEq for AccessSettings