pub struct ChatInviteJoinResultOk {
pub updates: Updates,
}Expand description
messages.chatInviteJoinResultOk
Generated from:
messages.chatInviteJoinResultOk#445663a7 updates:Updates = messages.ChatInviteJoinResultFields
updates: UpdatesTrait Implementations
Sourceimpl Clone for ChatInviteJoinResultOk
impl Clone for ChatInviteJoinResultOk
Sourcefn clone(&self) -> ChatInviteJoinResultOk
fn clone(&self) -> ChatInviteJoinResultOk
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChatInviteJoinResultOk
impl Debug for ChatInviteJoinResultOk
Sourceimpl Deserializable for ChatInviteJoinResultOk
impl Deserializable for ChatInviteJoinResultOk
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChatInviteJoinResultOk> for ChatInviteJoinResult
impl From<ChatInviteJoinResultOk> for ChatInviteJoinResult
Sourcefn from(x: ChatInviteJoinResultOk) -> Self
fn from(x: ChatInviteJoinResultOk) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChatInviteJoinResultOk
impl Identifiable for ChatInviteJoinResultOk
Sourceconst CONSTRUCTOR_ID: u32 = 0x445663a7
const CONSTRUCTOR_ID: u32 = 0x445663a7
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChatInviteJoinResultOk
impl PartialEq for ChatInviteJoinResultOk
Sourcefn eq(&self, other: &ChatInviteJoinResultOk) -> bool
fn eq(&self, other: &ChatInviteJoinResultOk) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ChatInviteJoinResultOk
Sourceimpl TryFrom<ChatInviteJoinResult> for ChatInviteJoinResultOk
impl TryFrom<ChatInviteJoinResult> for ChatInviteJoinResultOk
Sourcetype Error = ChatInviteJoinResult
type Error = ChatInviteJoinResult
The type returned in the event of a conversion error.