pub struct ChatInviteJoinResultWebView {
pub bot_id: i64,
pub webview: WebViewResult,
pub users: Vec<User>,
}Expand description
messages.chatInviteJoinResultWebView
Generated from:
messages.chatInviteJoinResultWebView#2f51c337 bot_id:long webview:WebViewResult users:Vector<User> = messages.ChatInviteJoinResultFields
bot_id: i64webview: WebViewResultusers: Vec<User>Trait Implementations
Sourceimpl Clone for ChatInviteJoinResultWebView
impl Clone for ChatInviteJoinResultWebView
Sourcefn clone(&self) -> ChatInviteJoinResultWebView
fn clone(&self) -> ChatInviteJoinResultWebView
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChatInviteJoinResultWebView
impl Debug for ChatInviteJoinResultWebView
Sourceimpl Deserializable for ChatInviteJoinResultWebView
impl Deserializable for ChatInviteJoinResultWebView
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChatInviteJoinResultWebView> for ChatInviteJoinResult
impl From<ChatInviteJoinResultWebView> for ChatInviteJoinResult
Sourcefn from(x: ChatInviteJoinResultWebView) -> Self
fn from(x: ChatInviteJoinResultWebView) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChatInviteJoinResultWebView
impl Identifiable for ChatInviteJoinResultWebView
Sourceconst CONSTRUCTOR_ID: u32 = 0x2f51c337
const CONSTRUCTOR_ID: u32 = 0x2f51c337
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChatInviteJoinResultWebView
impl PartialEq for ChatInviteJoinResultWebView
Sourcefn eq(&self, other: &ChatInviteJoinResultWebView) -> bool
fn eq(&self, other: &ChatInviteJoinResultWebView) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ChatInviteJoinResultWebView
Sourceimpl TryFrom<ChatInviteJoinResult> for ChatInviteJoinResultWebView
impl TryFrom<ChatInviteJoinResult> for ChatInviteJoinResultWebView
Sourcetype Error = ChatInviteJoinResult
type Error = ChatInviteJoinResult
The type returned in the event of a conversion error.