pub struct AiComposeTone {
pub creator: bool,
pub id: i64,
pub access_hash: i64,
pub slug: String,
pub title: String,
pub emoji_id: Option<i64>,
pub prompt: Option<String>,
pub installs_count: Option<i32>,
pub author_id: Option<i64>,
pub example_english: Option<AiComposeToneExample>,
}Expand description
Generated from:
aiComposeTone#cff63ea9 flags:# creator:flags.0?true id:long access_hash:long slug:string title:string emoji_id:flags.1?long prompt:flags.4?string installs_count:flags.2?int author_id:flags.3?long example_english:flags.5?AiComposeToneExample = AiComposeToneFields
creator: boolid: i64access_hash: i64slug: Stringtitle: Stringemoji_id: Option<i64>prompt: Option<String>installs_count: Option<i32>example_english: Option<AiComposeToneExample>Trait Implementations
Sourceimpl Clone for AiComposeTone
impl Clone for AiComposeTone
Sourcefn clone(&self) -> AiComposeTone
fn clone(&self) -> AiComposeTone
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AiComposeTone
impl Debug for AiComposeTone
Sourceimpl Deserializable for AiComposeTone
impl Deserializable for AiComposeTone
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<AiComposeTone> for AiComposeTone
impl From<AiComposeTone> for AiComposeTone
Sourcefn from(x: AiComposeTone) -> Self
fn from(x: AiComposeTone) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for AiComposeTone
impl Identifiable for AiComposeTone
Sourceconst CONSTRUCTOR_ID: u32 = 0xcff63ea9
const CONSTRUCTOR_ID: u32 = 0xcff63ea9
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for AiComposeTone
impl PartialEq for AiComposeTone
Sourcefn eq(&self, other: &AiComposeTone) -> bool
fn eq(&self, other: &AiComposeTone) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serializable for AiComposeTone
impl Serializable for AiComposeTone
Sourceimpl TryFrom<AiComposeTone> for AiComposeTone
impl TryFrom<AiComposeTone> for AiComposeTone
Sourcetype Error = AiComposeTone
type Error = AiComposeTone
The type returned in the event of a conversion error.
impl StructuralPartialEq for AiComposeTone