pub struct DraftMessage {
pub no_webpage: bool,
pub invert_media: bool,
pub reply_to: Option<InputReplyTo>,
pub message: String,
pub entities: Option<Vec<MessageEntity>>,
pub media: Option<InputMedia>,
pub date: i32,
pub effect: Option<i64>,
pub suggested_post: Option<SuggestedPost>,
pub rich_message: Option<RichMessage>,
}Expand description
Generated from:
draftMessage#60fe3294 flags:# no_webpage:flags.1?true invert_media:flags.6?true reply_to:flags.4?InputReplyTo message:string entities:flags.3?Vector<MessageEntity> media:flags.5?InputMedia date:int effect:flags.7?long suggested_post:flags.8?SuggestedPost rich_message:flags.9?RichMessage = DraftMessageFields
no_webpage: boolinvert_media: boolreply_to: Option<InputReplyTo>message: Stringentities: Option<Vec<MessageEntity>>media: Option<InputMedia>date: i32effect: Option<i64>suggested_post: Option<SuggestedPost>rich_message: Option<RichMessage>Trait Implementations
Sourceimpl Clone for DraftMessage
impl Clone for DraftMessage
Sourcefn clone(&self) -> DraftMessage
fn clone(&self) -> DraftMessage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DraftMessage
impl Debug for DraftMessage
Sourceimpl Deserializable for DraftMessage
impl Deserializable for DraftMessage
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<DraftMessage> for DraftMessage
impl From<DraftMessage> for DraftMessage
Sourcefn from(x: DraftMessage) -> Self
fn from(x: DraftMessage) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for DraftMessage
impl Identifiable for DraftMessage
Sourceconst CONSTRUCTOR_ID: u32 = 0x60fe3294
const CONSTRUCTOR_ID: u32 = 0x60fe3294
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for DraftMessage
impl PartialEq for DraftMessage
Sourcefn eq(&self, other: &DraftMessage) -> bool
fn eq(&self, other: &DraftMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serializable for DraftMessage
impl Serializable for DraftMessage
impl StructuralPartialEq for DraftMessage
Sourceimpl TryFrom<DraftMessage> for DraftMessage
impl TryFrom<DraftMessage> for DraftMessage
Sourcetype Error = DraftMessage
type Error = DraftMessage
The type returned in the event of a conversion error.