pub struct InputAiComposeToneId {
pub id: i64,
pub access_hash: i64,
}Expand description
Generated from:
inputAiComposeToneID#773c080 id:long access_hash:long = InputAiComposeToneFields
id: i64access_hash: i64Trait Implementations
Sourceimpl Clone for InputAiComposeToneId
impl Clone for InputAiComposeToneId
Sourcefn clone(&self) -> InputAiComposeToneId
fn clone(&self) -> InputAiComposeToneId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InputAiComposeToneId
impl Debug for InputAiComposeToneId
Sourceimpl Deserializable for InputAiComposeToneId
impl Deserializable for InputAiComposeToneId
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputAiComposeToneId> for InputAiComposeTone
impl From<InputAiComposeToneId> for InputAiComposeTone
Sourcefn from(x: InputAiComposeToneId) -> Self
fn from(x: InputAiComposeToneId) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputAiComposeToneId
impl Identifiable for InputAiComposeToneId
Sourceconst CONSTRUCTOR_ID: u32 = 0x0773c080
const CONSTRUCTOR_ID: u32 = 0x0773c080
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputAiComposeToneId
impl PartialEq for InputAiComposeToneId
Sourcefn eq(&self, other: &InputAiComposeToneId) -> bool
fn eq(&self, other: &InputAiComposeToneId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serializable for InputAiComposeToneId
impl Serializable for InputAiComposeToneId
Sourceimpl TryFrom<InputAiComposeTone> for InputAiComposeToneId
impl TryFrom<InputAiComposeTone> for InputAiComposeToneId
Sourcetype Error = InputAiComposeTone
type Error = InputAiComposeTone
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputAiComposeToneId