pub struct InputAiComposeToneSlug {
pub slug: String,
}Expand description
Generated from:
inputAiComposeToneSlug#1fa01357 slug:string = InputAiComposeToneFields
slug: StringTrait Implementations
Sourceimpl Clone for InputAiComposeToneSlug
impl Clone for InputAiComposeToneSlug
Sourcefn clone(&self) -> InputAiComposeToneSlug
fn clone(&self) -> InputAiComposeToneSlug
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InputAiComposeToneSlug
impl Debug for InputAiComposeToneSlug
Sourceimpl Deserializable for InputAiComposeToneSlug
impl Deserializable for InputAiComposeToneSlug
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputAiComposeToneSlug> for InputAiComposeTone
impl From<InputAiComposeToneSlug> for InputAiComposeTone
Sourcefn from(x: InputAiComposeToneSlug) -> Self
fn from(x: InputAiComposeToneSlug) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputAiComposeToneSlug
impl Identifiable for InputAiComposeToneSlug
Sourceconst CONSTRUCTOR_ID: u32 = 0x1fa01357
const CONSTRUCTOR_ID: u32 = 0x1fa01357
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputAiComposeToneSlug
impl PartialEq for InputAiComposeToneSlug
Sourcefn eq(&self, other: &InputAiComposeToneSlug) -> bool
fn eq(&self, other: &InputAiComposeToneSlug) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputAiComposeTone> for InputAiComposeToneSlug
impl TryFrom<InputAiComposeTone> for InputAiComposeToneSlug
Sourcetype Error = InputAiComposeTone
type Error = InputAiComposeTone
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputAiComposeToneSlug