pub struct InputRichMessageHtml {
pub rtl: bool,
pub noautolink: bool,
pub html: String,
pub files: Option<Vec<InputRichFile>>,
}Expand description
Generated from:
inputRichMessageHTML#dacb836a flags:# rtl:flags.0?true noautolink:flags.1?true html:string files:flags.2?Vector<InputRichFile> = InputRichMessageFields
rtl: boolnoautolink: boolhtml: Stringfiles: Option<Vec<InputRichFile>>Trait Implementations
Sourceimpl Clone for InputRichMessageHtml
impl Clone for InputRichMessageHtml
Sourcefn clone(&self) -> InputRichMessageHtml
fn clone(&self) -> InputRichMessageHtml
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InputRichMessageHtml
impl Debug for InputRichMessageHtml
Sourceimpl Deserializable for InputRichMessageHtml
impl Deserializable for InputRichMessageHtml
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputRichMessageHtml> for InputRichMessage
impl From<InputRichMessageHtml> for InputRichMessage
Sourcefn from(x: InputRichMessageHtml) -> Self
fn from(x: InputRichMessageHtml) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputRichMessageHtml
impl Identifiable for InputRichMessageHtml
Sourceconst CONSTRUCTOR_ID: u32 = 0xdacb836a
const CONSTRUCTOR_ID: u32 = 0xdacb836a
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputRichMessageHtml
impl PartialEq for InputRichMessageHtml
Sourcefn eq(&self, other: &InputRichMessageHtml) -> bool
fn eq(&self, other: &InputRichMessageHtml) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serializable for InputRichMessageHtml
impl Serializable for InputRichMessageHtml
impl StructuralPartialEq for InputRichMessageHtml
Sourceimpl TryFrom<InputRichMessage> for InputRichMessageHtml
impl TryFrom<InputRichMessage> for InputRichMessageHtml
Sourcetype Error = InputRichMessage
type Error = InputRichMessage
The type returned in the event of a conversion error.