pub struct InputRichMessageMarkdown {
pub rtl: bool,
pub noautolink: bool,
pub markdown: String,
pub files: Option<Vec<InputRichFile>>,
}Expand description
Generated from:
inputRichMessageMarkdown#4b572c flags:# rtl:flags.0?true noautolink:flags.1?true markdown:string files:flags.2?Vector<InputRichFile> = InputRichMessageFields
rtl: boolnoautolink: boolmarkdown: Stringfiles: Option<Vec<InputRichFile>>Trait Implementations
Sourceimpl Clone for InputRichMessageMarkdown
impl Clone for InputRichMessageMarkdown
Sourcefn clone(&self) -> InputRichMessageMarkdown
fn clone(&self) -> InputRichMessageMarkdown
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InputRichMessageMarkdown
impl Debug for InputRichMessageMarkdown
Sourceimpl Deserializable for InputRichMessageMarkdown
impl Deserializable for InputRichMessageMarkdown
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputRichMessageMarkdown> for InputRichMessage
impl From<InputRichMessageMarkdown> for InputRichMessage
Sourcefn from(x: InputRichMessageMarkdown) -> Self
fn from(x: InputRichMessageMarkdown) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputRichMessageMarkdown
impl Identifiable for InputRichMessageMarkdown
Sourceconst CONSTRUCTOR_ID: u32 = 0x004b572c
const CONSTRUCTOR_ID: u32 = 0x004b572c
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputRichMessageMarkdown
impl PartialEq for InputRichMessageMarkdown
Sourcefn eq(&self, other: &InputRichMessageMarkdown) -> bool
fn eq(&self, other: &InputRichMessageMarkdown) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for InputRichMessageMarkdown
Sourceimpl TryFrom<InputRichMessage> for InputRichMessageMarkdown
impl TryFrom<InputRichMessage> for InputRichMessageMarkdown
Sourcetype Error = InputRichMessage
type Error = InputRichMessage
The type returned in the event of a conversion error.