pub struct InputStorePaymentAuthCode {
pub restore: bool,
pub phone_number: String,
pub phone_code_hash: String,
pub premium_days: i32,
pub currency: String,
pub amount: i64,
}Expand description
Generated from:
inputStorePaymentAuthCode#3fc18057 flags:# restore:flags.0?true phone_number:string phone_code_hash:string premium_days:int currency:string amount:long = InputStorePaymentPurposeFields
restore: boolphone_number: Stringphone_code_hash: Stringcurrency: Stringamount: i64Trait Implementations
Sourceimpl Clone for InputStorePaymentAuthCode
impl Clone for InputStorePaymentAuthCode
Sourcefn clone(&self) -> InputStorePaymentAuthCode
fn clone(&self) -> InputStorePaymentAuthCode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InputStorePaymentAuthCode
impl Debug for InputStorePaymentAuthCode
Sourceimpl Deserializable for InputStorePaymentAuthCode
impl Deserializable for InputStorePaymentAuthCode
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputStorePaymentAuthCode> for InputStorePaymentPurpose
impl From<InputStorePaymentAuthCode> for InputStorePaymentPurpose
Sourcefn from(x: InputStorePaymentAuthCode) -> Self
fn from(x: InputStorePaymentAuthCode) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputStorePaymentAuthCode
impl Identifiable for InputStorePaymentAuthCode
Sourceconst CONSTRUCTOR_ID: u32 = 0x3fc18057
const CONSTRUCTOR_ID: u32 = 0x3fc18057
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputStorePaymentAuthCode
impl PartialEq for InputStorePaymentAuthCode
Sourcefn eq(&self, other: &InputStorePaymentAuthCode) -> bool
fn eq(&self, other: &InputStorePaymentAuthCode) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputStorePaymentPurpose> for InputStorePaymentAuthCode
impl TryFrom<InputStorePaymentPurpose> for InputStorePaymentAuthCode
Sourcetype Error = InputStorePaymentPurpose
type Error = InputStorePaymentPurpose
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputStorePaymentAuthCode