pub struct JoinChatBotResultWebView {
pub url: String,
}Expand description
Generated from:
joinChatBotResultWebView#d6e3b813 url:string = JoinChatBotResultFields
url: StringTrait Implementations
Sourceimpl Clone for JoinChatBotResultWebView
impl Clone for JoinChatBotResultWebView
Sourcefn clone(&self) -> JoinChatBotResultWebView
fn clone(&self) -> JoinChatBotResultWebView
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JoinChatBotResultWebView
impl Debug for JoinChatBotResultWebView
Sourceimpl Deserializable for JoinChatBotResultWebView
impl Deserializable for JoinChatBotResultWebView
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<JoinChatBotResultWebView> for JoinChatBotResult
impl From<JoinChatBotResultWebView> for JoinChatBotResult
Sourcefn from(x: JoinChatBotResultWebView) -> Self
fn from(x: JoinChatBotResultWebView) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for JoinChatBotResultWebView
impl Identifiable for JoinChatBotResultWebView
Sourceconst CONSTRUCTOR_ID: u32 = 0xd6e3b813
const CONSTRUCTOR_ID: u32 = 0xd6e3b813
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for JoinChatBotResultWebView
impl PartialEq for JoinChatBotResultWebView
Sourcefn eq(&self, other: &JoinChatBotResultWebView) -> bool
fn eq(&self, other: &JoinChatBotResultWebView) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for JoinChatBotResultWebView
Sourceimpl TryFrom<JoinChatBotResult> for JoinChatBotResultWebView
impl TryFrom<JoinChatBotResult> for JoinChatBotResultWebView
Sourcetype Error = JoinChatBotResult
type Error = JoinChatBotResult
The type returned in the event of a conversion error.