pub struct RichMessage {
pub rtl: bool,
pub part: bool,
pub blocks: Vec<PageBlock>,
pub photos: Vec<Photo>,
pub documents: Vec<Document>,
}Expand description
Generated from:
richMessage#baf39d8b flags:# rtl:flags.0?true part:flags.1?true blocks:Vector<PageBlock> photos:Vector<Photo> documents:Vector<Document> = RichMessageFields
rtl: boolpart: boolblocks: Vec<PageBlock>photos: Vec<Photo>documents: Vec<Document>Trait Implementations
Sourceimpl Clone for RichMessage
impl Clone for RichMessage
Sourcefn clone(&self) -> RichMessage
fn clone(&self) -> RichMessage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RichMessage
impl Debug for RichMessage
Sourceimpl Deserializable for RichMessage
impl Deserializable for RichMessage
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<RichMessage> for RichMessage
impl From<RichMessage> for RichMessage
Sourcefn from(x: RichMessage) -> Self
fn from(x: RichMessage) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for RichMessage
impl Identifiable for RichMessage
Sourceconst CONSTRUCTOR_ID: u32 = 0xbaf39d8b
const CONSTRUCTOR_ID: u32 = 0xbaf39d8b
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for RichMessage
impl PartialEq for RichMessage
Sourcefn eq(&self, other: &RichMessage) -> bool
fn eq(&self, other: &RichMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serializable for RichMessage
impl Serializable for RichMessage
impl StructuralPartialEq for RichMessage
Sourceimpl TryFrom<RichMessage> for RichMessage
impl TryFrom<RichMessage> for RichMessage
Sourcetype Error = RichMessage
type Error = RichMessage
The type returned in the event of a conversion error.