pub struct SendMessageRichMessageDraftAction {
pub random_id: i64,
pub rich_message: RichMessage,
}Expand description
sendMessageRichMessageDraftAction
Generated from:
sendMessageRichMessageDraftAction#a2cb24f9 random_id:long rich_message:RichMessage = SendMessageActionFields
random_id: i64rich_message: RichMessageTrait Implementations
Sourceimpl Clone for SendMessageRichMessageDraftAction
impl Clone for SendMessageRichMessageDraftAction
Sourcefn clone(&self) -> SendMessageRichMessageDraftAction
fn clone(&self) -> SendMessageRichMessageDraftAction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for SendMessageRichMessageDraftAction
impl Deserializable for SendMessageRichMessageDraftAction
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<SendMessageRichMessageDraftAction> for SendMessageAction
impl From<SendMessageRichMessageDraftAction> for SendMessageAction
Sourcefn from(x: SendMessageRichMessageDraftAction) -> Self
fn from(x: SendMessageRichMessageDraftAction) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for SendMessageRichMessageDraftAction
impl Identifiable for SendMessageRichMessageDraftAction
Sourceconst CONSTRUCTOR_ID: u32 = 0xa2cb24f9
const CONSTRUCTOR_ID: u32 = 0xa2cb24f9
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for SendMessageRichMessageDraftAction
impl PartialEq for SendMessageRichMessageDraftAction
Sourcefn eq(&self, other: &SendMessageRichMessageDraftAction) -> bool
fn eq(&self, other: &SendMessageRichMessageDraftAction) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SendMessageRichMessageDraftAction
Sourceimpl TryFrom<SendMessageAction> for SendMessageRichMessageDraftAction
impl TryFrom<SendMessageAction> for SendMessageRichMessageDraftAction
Sourcetype Error = SendMessageAction
type Error = SendMessageAction
The type returned in the event of a conversion error.