pub struct WebPageAttributeAiComposeTone {
pub emoji_id: i64,
}Expand description
Generated from:
webPageAttributeAiComposeTone#7781fe18 emoji_id:long = WebPageAttributeFields
emoji_id: i64Trait Implementations
Sourceimpl Clone for WebPageAttributeAiComposeTone
impl Clone for WebPageAttributeAiComposeTone
Sourcefn clone(&self) -> WebPageAttributeAiComposeTone
fn clone(&self) -> WebPageAttributeAiComposeTone
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for WebPageAttributeAiComposeTone
impl Deserializable for WebPageAttributeAiComposeTone
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<WebPageAttributeAiComposeTone> for WebPageAttribute
impl From<WebPageAttributeAiComposeTone> for WebPageAttribute
Sourcefn from(x: WebPageAttributeAiComposeTone) -> Self
fn from(x: WebPageAttributeAiComposeTone) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for WebPageAttributeAiComposeTone
impl Identifiable for WebPageAttributeAiComposeTone
Sourceconst CONSTRUCTOR_ID: u32 = 0x7781fe18
const CONSTRUCTOR_ID: u32 = 0x7781fe18
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for WebPageAttributeAiComposeTone
impl PartialEq for WebPageAttributeAiComposeTone
Sourcefn eq(&self, other: &WebPageAttributeAiComposeTone) -> bool
fn eq(&self, other: &WebPageAttributeAiComposeTone) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<WebPageAttribute> for WebPageAttributeAiComposeTone
impl TryFrom<WebPageAttribute> for WebPageAttributeAiComposeTone
Sourcetype Error = WebPageAttribute
type Error = WebPageAttribute
The type returned in the event of a conversion error.
impl StructuralPartialEq for WebPageAttributeAiComposeTone