Module deserialize
ferogram_
tl_
types
0.3.8
Module deserialize
Module Items
Structs
Enums
Traits
Functions
Type Aliases
In crate ferogram_
tl_
types
ferogram_tl_types
Module
deserialize
Structs

Cursor
A zero-copy cursor over an in-memory byte slice.
Enums

Error
Errors that can occur during deserialization.
Traits

Deserializable
Deserialize a value from TL binary format.
Functions

tl_
debug
Returns
true
when the
FEROGRAM_TL_DEBUG
environment variable is set to any non-empty value. The result is cached after the first call so there is zero overhead in hot deserialisation paths when debugging is off.
Type Aliases

Buffer
Alias used by generated code:
crate::deserialize::Buffer<'_, '_>
.
Result
Specialized
Result
for deserialization.